# Reactive Signal Inference

This is a reference implementation of the Resin (Reactive Signal Inference) language and Reactive Circuits (RCs).

If you encounter an issue during compilation regarding the building of Clingo with cmake, a possible solution is `export CMAKE_POLICY_VERSION_MINIMUM=3.5`.